@@ -312,11 +312,9 @@ TSPRegistryMapping = {
     "3098": "TSD.SetCaptionOrTitleVisibilityCommandArchive",
     "4000": "TSCE.CalculationEngineArchive",
     "4001": "TSCE.FormulaRewriteCommandArchive",
-    "4002": "TSCE.TrackedReferencesRewriteCommandArchive",
     "4003": "TSCE.NamedReferenceManagerArchive",
-    "4004": "TSCE.ReferenceTrackerArchive",
+    "4004": "TSCE.TrackedReferenceStoreArchive",
     "4005": "TSCE.TrackedReferenceArchive",
-    "4006": "TSCE.ExtendTableIDHistoryCommandArchive",
     "4007": "TSCE.RemoteDataStoreArchive",
     "4008": "TSCE.FormulaOwnerDependenciesArchive",
     "4009": "TSCE.CellRecordTileArchive",
@@ -385,6 +383,7 @@ TSPRegistryMapping = {
     "5154": "TSCH.CommandPasteStyleArchive",
     "5155": "TSCH.CommandInducedReplaceChartGrid",
     "5156": "TSCH.CommandReplaceImageDataArchive",
+    "5157": "TSCH.CommandInduced3DChartGeometry",
     "6000": "TST.TableInfoArchive",
     "6001": "TST.TableModelArchive",
     "6002": "TST.Tile",
@@ -435,6 +434,7 @@ TSPRegistryMapping = {
     "6156": "TST.CommandSetPencilAnnotationsArchive",
     "6157": "TST.CommandCategoryWillChangeGroupValue",
     "6158": "TST.CommandApplyConcurrentCellMapArchive",
+    "6159": "TST.CommandSetGroupSortOrderArchive",
     "6179": "TST.FormulaEqualsTokenAttachmentArchive",
     "6181": "TST.TokenAttachmentArchive",
     "6182": "TST.ExpressionNodeArchive",
@@ -545,6 +545,18 @@ TSPRegistryMapping = {
     "6366": "TST.HeaderNameMgrArchive",
     "6367": "TST.CellDiffArray",
     "6368": "TST.CellDiffArraySegment",
+    "6369": "TST.PivotOrderArchive",
+    "6370": "TST.PivotOwnerArchive",
+    "6371": "TST.CommandPivotSetPivotRulesArchive",
+    "6372": "TST.CategoryOwnerRefArchive",
+    "6373": "TST.GroupByArchive",
+    "6374": "TST.PivotGroupingColumnOptionsMapArchive",
+    "6375": "TST.CommandPivotSetGroupingColumnOptionsArchive",
+    "6376": "TST.CommandPivotHideShowGrandTotalsArchive",
+    "6377": "TST.CommandPivotSortArchive",
+    "6379": "TST.CommandRewritePivotOwnerFormulasArchive",
+    "6380": "TST.CommandRewriteTrackedReferencesArchive",
+    "6381": "TST.CommandExtendTableIDHistoryArchive",
     "10011": "TSWP.SectionPlaceholderArchive",
     "10020": "TSWP.ShapeSelectionTransformerArchive",
     "10021": "TSWP.SelectionTransformerArchive",
@@ -612,6 +624,10 @@ TSPRegistryMapping = {
     "12052": "TN.CommandSetPrintBackgroundsArchive",
     "12053": "TN.FormBuilderSelectionArchive",
     "12054": "TN.FormTableChooserSelectionArchive",
+    "12055": "TN.FormTableChooserSelectionTransformerArchive",
+    "12056": "TN.FormBuilderSelectionTransformerArchive",
+    "12057": "TN.FormViewerSelectionTransformerArchive",
+    "12058": "TN.FormSheetSelectionTransformerArchive",
 }
 
 
